@@ -124,7 +124,7 @@ NULL
 #'    \item{`c`}{`numeric` (**optional**) minimum probability of persistence of a
 #'    features when a threat reaches its maximum intensity value. Default is 0.}
 #'    \item{`d`}{`numeric` (**optional**) maximum probability of persistence of a
-#'    features in absence of a given threat. Default is 1.}
+#'    features in absence threats. Default is 1.}
 #'    }
 #'  Note that optional parameters *a*, *b*, *c* and *d* can be provided independently.
 #'
@@ -244,6 +244,7 @@ methods::setMethod(
     } else {
       pu$status <- 0
     }
+    pu <- pu[order(pu$id),]
 
     ## features
     assertthat::assert_that(
@@ -465,9 +466,10 @@ methods::setMethod(
         is.numeric(boundary$boundary),
         assertthat::noNA(boundary$id1),
         assertthat::noNA(boundary$id2),
-        assertthat::noNA(boundary$boundary),
-        all(boundary$id1 %in% pu$id), all(boundary$id2 %in% pu$id)
+        assertthat::noNA(boundary$boundary)
+        #all(boundary$id1 %in% pu$id), all(boundary$id2 %in% pu$id)
       )
+      boundary$boundary <- base::round(boundary$boundary, 3)
     }
 
 
@@ -518,6 +520,16 @@ methods::setMethod(
       threats <- threats[!threats$id %in% dif_threats_dangerous, ]
       dist_threats <- dist_threats[!dist_threats$threat %in% dif_threats_dangerous, ]
     }
+    if(!is.null(boundary)){
+      if(!all(boundary$id1 %in% pu$id) || !all(boundary$id2 %in% pu$id)){
+        warning("The boundary data contain pu which ids does not exist in pu data (it'll not be considered in the model)", call. = FALSE, immediate. = TRUE)
+
+        rows_boundary_leftover <- c(which(!boundary$id1 %in% pu$id), which(!boundary$id2 %in% pu$id))
+        boundary <- boundary[-rows_boundary_leftover,]
+      }
+    }
+
+
 
     ## Rounding numeric fields of input data
     pu$monitoring_cost <- base::round(pu$monitoring_cost, 3)
@@ -531,7 +543,7 @@ methods::setMethod(
     sensitivity$b <- base::round(sensitivity$b, 3)
     sensitivity$c <- base::round(sensitivity$c, 3)
     sensitivity$d <- base::round(sensitivity$d, 3)
-    boundary$boundary <- base::round(boundary$boundary, 3)
+
 
 
     ## Creating internal id's
